'use strict';

const kit = require('@nuxt/kit');
const vite = require('vite');
const config = require('./config.cjs');
const getPortPlease = require('get-port-please');

const vitePluginBlocklist = ["vite-plugin-vue-inspector", "vite-plugin-inspect"];
const module$1 = kit.defineNuxtModule({
  meta: {
    name: "nuxt-vitest",
    configKey: "vitest"
  },
  defaults: {
    startOnBoot: false,
    logToConsole: false
  },
  async setup(options, nuxt) {
    await kit.installModule("vitest-environment-nuxt/module");
    if (!nuxt.options.dev)
      return;
    if (process.env.TEST || process.env.VITE_TEST)
      return;
    const rawViteConfigPromise = new Promise((resolve) => {
      nuxt.hook("app:resolve", () => {
        nuxt.hook("vite:extendConfig", (config, { isClient }) => {
          if (isClient)
            resolve(config);
        });
      });
    });
    const PORT = await getPortPlease.getPort({ port: 15555 });
    const URL = `http://localhost:${PORT}/__vitest__/`;
    let loaded = false;
    let promise;
    async function start() {
      const rawViteConfig = vite.mergeConfig({}, await rawViteConfigPromise);
      const viteConfig = vite.mergeConfig(
        await config.getVitestConfigFromNuxt({ nuxt, viteConfig: rawViteConfig }),
        {
          server: {
            middlewareMode: false
          }
        }
      );
      viteConfig.plugins = (viteConfig.plugins || []).filter((p) => {
        return !vitePluginBlocklist.includes(p?.name);
      });
      process.env.__NUXT_VITEST_RESOLVED__ = "true";
      const { startVitest } = await import(await kit.resolvePath("vitest/node"));
      const vitestConfig = process.env.NUXT_VITEST_DEV_TEST ? {
        ...options.vitestConfig,
        watch: false
      } : {
        ...options.vitestConfig,
        reporters: options.logToConsole ? void 0 : [{}],
        // do not report to console
        ui: true,
        open: false,
        api: {
          port: PORT
        }
      };
      viteConfig.configFile = false;
      const promise2 = startVitest("test", [], vitestConfig, viteConfig);
      if (process.env.NUXT_VITEST_DEV_TEST) {
        promise2.then((v) => v?.close()).then(() => process.exit());
        promise2.catch(() => process.exit(1));
      }
      kit.logger.info(`Vitest UI starting on ${URL}`);
      loaded = true;
    }
    nuxt.hook("devtools:customTabs", (tabs) => {
      tabs.push({
        title: "Vitest",
        name: "vitest",
        icon: "logos-vitest",
        view: loaded ? {
          type: "iframe",
          src: URL
        } : {
          type: "launch",
          description: "Start tests along with Nuxt",
          actions: [
            {
              label: promise ? "Starting..." : "Start Vitest",
              pending: !!promise,
              handle: () => {
                promise = promise || start();
                return promise;
              }
            }
          ]
        }
      });
    });
    if (options.startOnBoot) {
      promise = promise || start();
      promise.then(() => {
        nuxt.callHook("devtools:customTabs:refresh");
      });
    }
  }
});

module.exports = module$1;
